ValueLabel — pyqtgraph 0.11.0rc0 documentation

# ValueLabel

class `pyqtgraph.` `ValueLabel`(parent=None, suffix='', siPrefix=False, averageTime=0, formatStr=None)

  QLabel specifically for displaying numerical values. Extends QLabel adding some extra functionality:

  - displaying units with si prefix

  - built-in exponential averaging

  `__init__`(parent=None, suffix='', siPrefix=False, averageTime=0, formatStr=None)

    Arguments: |
    suffix | (str or None) The suffix to place after the value
    siPrefix | (bool) Whether to add an SI prefix to the units and display a scaled value
    averageTime | (float) The length of time in seconds to average values. If this value is 0, then no averaging is performed. As this value increases the display value will appear to change more slowly and smoothly.
    formatStr | (str) Optionally, provide a format string to use when displaying text. The text will be generated by calling formatStr.format(value=, avgValue=, suffix=) (see Python documentation on str.format) This option is not compatible with siPrefix

  `paintEvent`(self, arg__1: PySide2.QtGui.QPaintEvent)